@@ -6,6 +6,9 @@ from torch.distributions.normal import Normal
 from ..neural_networks.feature_extractors.utils import init
 
 
+LOG_STD_MAX = 2 # Maximum std allowed value. Used for clipping.
+LOG_STD_MIN = -20 # Minimum std allowed value. Used for clipping.
+
 class SquashedGaussian(nn.Module):
     """
     Squashed Gaussian action distribution.
@@ -28,9 +31,6 @@ class SquashedGaussian(nn.Module):
         action std values. Otherwise, the std values are a learnable nn.Parameter.
     """
 
-    LOG_STD_MAX = 2 # Maximum std allowed value. Used for clipping.
-    LOG_STD_MIN = -20 # Minimum std allowed value. Used for clipping.
-
     def __init__(self, num_inputs, num_outputs, predict_log_std=True):
         super(SquashedGaussian, self).__init__()
 
@@ -72,7 +72,7 @@ class SquashedGaussian(nn.Module):
         action_mean = self.mean(x)
         action_logstd = self.log_std(x) if self.predict_log_std else\
             torch.zeros(action_mean.size()).to(x.device) + self.log_std
-        action_logstd = torch.clamp(action_logstd, self.LOG_STD_MIN, self.LOG_STD_MAX)
+        action_logstd = torch.clamp(action_logstd, LOG_STD_MIN, LOG_STD_MAX)
 
         # Create distribution and sample action
         action_dist = Normal(action_mean, action_logstd.exp())
